@@ -1,6 +1,10 @@
 # import datetime
+import json
+
 import nonebot
-import requests
+# import requests
+# import asyncio
+import aiohttp
 import time
 # from io import BytesIO
 from nonebot import on_keyword
@@ -31,11 +35,14 @@ from .data import DATA
 /查收益 昵称关键词或uid 收益类型(默认1: 礼物，2: 上舰，3: SC) 倒叙第n场(从0开始)
 /查成分 观看 昵称关键词或uid
 /查成分 弹幕 查询的目标人昵称关键词或uid 查询的主播昵称关键词或uid 页数 条数
+/营收 日/周/月榜 人数（不填默认100）
 '''
 
 # 请求头贴入你的b站cookie
 header1 = {
-    'cookie': ''
+    'content-type': 'text/plain; charset=utf-8',
+    'cookie': '',
+    'user-agent': 'Mozilla/5.0 (Windows NT 10.0; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/94.0.4606.71 Safari/537.36 Core/1.94.186.400 QQBrowser/11.3.5195.400'
 }
 
 # 获取env配置
@@ -49,10 +56,11 @@ except:
 nonebot.logger.debug("cookie=" + header1["cookie"])
 
 catch_str = on_keyword({'/查 '})
+
+
 @catch_str.handle()
-async def send_msg(bot: Bot, event: Event, state: T_State):
+async def _(bot: Bot, event: Event, state: T_State):
     get_msg = str(event.get_message())
-    id = event.get_user_id()
     # nonebot.logger.info(get_msg)
     content = get_msg[3:]
 
@@ -100,13 +108,16 @@ async def send_msg(bot: Bot, event: Event, state: T_State):
         guard_info_json = await get_guard_info(content, room_id)
 
     msg = '\n用户名：' + base_info_json['card']['name'] + '\nUID：' + str(base_info_json['card']['mid']) + \
-          '\n房间号：' + str(room_id) + '\n粉丝数：' + str(base_info_json['card']['fans']) + '\n舰团数：' + str(guard_info_json['data']['info']['num'])
+          '\n房间号：' + str(room_id) + '\n粉丝数：' + str(base_info_json['card']['fans']) + '\n舰团数：' + str(
+        guard_info_json['data']['info']['num'])
     await catch_str.finish(Message(f'{msg}'), at_sender=True)
 
 
 catch_str1 = on_keyword({'/查成分 弹幕 '})
+
+
 @catch_str1.handle()
-async def send_msg(bot: Bot, event: Event, state: T_State):
+async def _(bot: Bot, event: Event, state: T_State):
     get_msg = str(event.get_message())
     # nonebot.logger.info(get_msg)
     content = get_msg[8:]
@@ -212,6 +223,7 @@ async def send_msg(bot: Bot, event: Event, state: T_State):
                 out_str += '| ' + str(date) + '| ' + message + '|\n'
                 data_len += 1
             out_str += '| -- | -- |\n'
+        out_str += '\n数据源自：danmaku.suki.club\n'
     # nonebot.logger.info("\n" + out_str)
     except (KeyError, TypeError, IndexError) as e:
         msg = '返回数据解析异常，寄~'
@@ -228,8 +240,10 @@ async def send_msg(bot: Bot, event: Event, state: T_State):
 
 
 catch_str2 = on_keyword({'/查成分 观看 '})
+
+
 @catch_str2.handle()
-async def send_msg2(bot: Bot, event: Event, state: T_State):
+async def _(bot: Bot, event: Event, state: T_State):
     get_msg = str(event.get_message())
     # nonebot.logger.info(get_msg)
     content = get_msg[8:]
@@ -276,7 +290,7 @@ async def send_msg2(bot: Bot, event: Event, state: T_State):
         await catch_str2.finish(Message(f'{msg}'), at_sender=True)
 
     out_str = "#查观看\n\n查询用户UID：" + content + "\n\n" + \
-              "| 昵称 | UID | 房间号 |\n"\
+              "| 昵称 | UID | 房间号 |\n" \
               "| :-----| :-----| :-----|\n"
     # 数据集合
     name_set = set()
@@ -301,6 +315,7 @@ async def send_msg2(bot: Bot, event: Event, state: T_State):
     for i in range(len(uId_set)):
         out_str += "| {:<s} | {:<d} | {:<d} |".format(name_list[i], uId_list[i], roomId_list[i])
         out_str += '\n'
+    out_str += '\n数据源自：danmaku.suki.club\n'
     # nonebot.logger.info("\n" + out_str)
 
     if len(uId_set) < 1000:
@@ -312,8 +327,10 @@ async def send_msg2(bot: Bot, event: Event, state: T_State):
 
 
 catch_str3 = on_keyword({'/查直播 '})
+
+
 @catch_str3.handle()
-async def send_msg3(bot: Bot, event: Event, state: T_State):
+async def _(bot: Bot, event: Event, state: T_State):
     get_msg = str(event.get_message())
     id = event.get_user_id()
     # nonebot.logger.info(get_msg)
@@ -400,7 +417,8 @@ async def send_msg3(bot: Bot, event: Event, state: T_State):
             else:
                 out_str += "| {:<s} | {:<.2f}h | {:<s} | {:<d} | {:<d} | {:<d} | ￥{:<.1f} |".format(
                     await timestamp_to_date(info_json["data"]["lives"][i]["startDate"]),
-                    (info_json["data"]["lives"][i]["stopDate"] - info_json["data"]["lives"][i]["startDate"]) / 1000 / 3600,
+                    (info_json["data"]["lives"][i]["stopDate"] - info_json["data"]["lives"][i][
+                        "startDate"]) / 1000 / 3600,
                     info_json["data"]["lives"][i]["title"],
                     info_json["data"]["lives"][i]["danmakusCount"],
                     info_json["data"]["lives"][i]["watchCount"],
@@ -418,6 +436,7 @@ async def send_msg3(bot: Bot, event: Event, state: T_State):
         # 2000场就算了吧，太多了
         if i >= 2000:
             break
+    out_str += '\n数据源自：danmaku.suki.club\n'
     # nonebot.logger.info("\n" + out_str)
 
     if len(info_json["data"]["lives"]) < 2000:
@@ -430,8 +449,10 @@ async def send_msg3(bot: Bot, event: Event, state: T_State):
 
 
 catch_str4 = on_keyword({'/查收益 '})
+
+
 @catch_str4.handle()
-async def send_msg4(bot: Bot, event: Event, state: T_State):
+async def _(bot: Bot, event: Event, state: T_State):
     get_msg = str(event.get_message())
     id = event.get_user_id()
     # nonebot.logger.info(get_msg)
@@ -548,6 +569,7 @@ async def send_msg4(bot: Bot, event: Event, state: T_State):
         # 2000条就算了吧，太多了
         if i >= 2000:
             break
+    out_str += '\n数据源自：danmaku.suki.club\n'
     # nonebot.logger.info("\n" + out_str)
 
     if len(info_json["data"]["danmakus"]) < 2000:
@@ -559,8 +581,10 @@ async def send_msg4(bot: Bot, event: Event, state: T_State):
 
 
 catch_str5 = on_keyword({'/查舰团 '})
+
+
 @catch_str5.handle()
-async def send_img(bot: Bot, event: Event, state: T_State):
+async def _(bot: Bot, event: Event, state: T_State):
     get_msg = str(event.get_message())
     # nonebot.logger.info(get_msg)
     content = get_msg[5:]
@@ -587,7 +611,7 @@ async def send_img(bot: Bot, event: Event, state: T_State):
     if flag != 1:
         # 通过昵称查询uid，默认只查搜索到的第一个用户
         info_json = await use_name_get_uid(content)
-        # nonebot.logger.info(info_json)
+        nonebot.logger.info(info_json)
 
         try:
             result = info_json['data']['result']
@@ -613,6 +637,7 @@ async def send_img(bot: Bot, event: Event, state: T_State):
             level = '舰长'
         out_str += "| {:<s} | {:<d} | {:<s} |".format(uname, mid, level)
         out_str += '\n'
+    out_str += '\n数据源自：vtbs.moe\n'
     # nonebot.logger.info("\n" + out_str)
 
     output = await md_to_pic(md=out_str, width=500)
@@ -620,8 +645,10 @@ async def send_img(bot: Bot, event: Event, state: T_State):
 
 
 catch_str6 = on_keyword({'/查昵称 '})
+
+
 @catch_str6.handle()
-async def send_msg(bot: Bot, event: Event, state: T_State):
+async def _(bot: Bot, event: Event, state: T_State):
     get_msg = str(event.get_message())
     # nonebot.logger.info(get_msg)
     content = get_msg[5:]
@@ -644,6 +671,100 @@ async def send_msg(bot: Bot, event: Event, state: T_State):
     await catch_str6.finish(Message(f'{msg}'), at_sender=True)
 
 
+catch_str7 = on_keyword({'/营收 '})
+
+
+@catch_str7.handle()
+async def _(bot: Bot, event: Event, state: T_State):
+    get_msg = str(event.get_message())
+    content = get_msg[4:]
+
+    # 分别传入 日/周/月榜 和 数量
+    content = content.split()
+    date_range = ''
+    size = '100'
+
+    if len(content) == 1:
+        date_range = content[0]
+    elif len(content) >= 2:
+        date_range = content[0]
+        size = content[1]
+
+    date_ranges = ['月榜', '周榜', '日榜']
+    if date_range in date_ranges:
+        json1 = await get_revenue(date_range, size)
+    else:
+        msg = '\n命令错误，例如：【/营收 月榜】【/营收 周榜 10】【/营收 日榜 3】'
+        await catch_str7.finish(Message(f'{msg}'), at_sender=True)
+        return
+
+    try:
+        if json1["code"] != 200:
+            msg = '\n请求失败，寄了喵'
+            await catch_str7.finish(Message(f'{msg}'), at_sender=True)
+            return
+    except (KeyError, TypeError, IndexError) as e:
+        msg = '\n请求失败，寄了喵'
+        await catch_str7.finish(Message(f'{msg}'), at_sender=True)
+        return
+
+    try:
+        out_str = "#VTB营收" + date_range + "\n" + \
+                  "| 用户名 | uid | 营收 | 付费人数 | 弹幕总数 | 直播时长 |\n" \
+                  "| :-----| :-----| :-----| :-----| :-----| :-----|\n"
+        for i in range(len(json1['data'])):
+            name = json1['data'][i]['name']
+            danmaku = json1['data'][i]['danmaku']
+            gold_user = json1['data'][i]['goldUser']
+            income = json1['data'][i]['income']
+            mid = json1['data'][i]['mid']
+            live_time = json1['data'][i]['liveTime']
+
+            out_str += '| ' + name + ' | ' + str(mid) + ' | '
+            if income > 1000000:
+                income = round(income / 1000000, 2)
+                out_str += str(income) + '万 | '
+            else:
+                income = round(income / 100, 2)
+                out_str += str(income) + '元 | '
+            out_str += str(gold_user) + '人 | ' + str(danmaku) + '条 | '
+            live_time = round(live_time / 60 / 60, 2)
+            out_str += str(live_time) + 'h |' + '\n'
+
+        out_str += "\n\n数据源自：vtbs.fun"
+        # nonebot.logger.info("\n" + out_str)
+
+        output = await md_to_pic(md=out_str, width=800)
+        # 如果需要保存到本地则去除下面2行注释
+        # output = Image.open(BytesIO(img))
+        # output.save("md2pic.png", format="PNG")
+        await catch_str7.send(MessageSegment.image(output))
+    except (KeyError, TypeError, IndexError) as e:
+        msg = '\n数据解析失败，寄了喵'
+        await catch_str7.finish(Message(f'{msg}'), at_sender=True)
+        return
+
+
+# 获取营收榜单信息 传入 日/周/月榜 和 数量
+async def get_revenue(date_range, size):
+    if date_range == '日榜':
+        date_range = '%E6%97%A5%E6%A6%9C'
+    elif date_range == '周榜':
+        date_range = '%E5%91%A8%E6%A6%9C'
+    elif date_range == '月榜':
+        date_range = '%E6%9C%88%E6%A6%9C'
+    else:
+        date_range = '%E6%9C%88%E6%A6%9C'
+
+    API_URL = 'http://www.vtbs.fun:8050/rank/income?dateRange=' + date_range + '&current=1&size=' + size
+    # nonebot.logger.info("API_URL=" + API_URL)
+    async with aiohttp.ClientSession(headers=header1) as session:
+        async with session.get(url=API_URL, headers=header1) as response:
+            ret = await response.json()
+    # nonebot.logger.info(ret)
+    return ret
+
+
 # 数据预处理
 def data_preprocess(content):
     # 由于逻辑问题 查uid时需要追加(以:或：或uid:或UID:打头)在命令后
@@ -659,8 +780,10 @@ def data_preprocess(content):
 # 传入uid获取用户基本信息
 async def get_base_info(uid):
     API_URL = 'https://account.bilibili.com/api/member/getCardByMid?mid=' + uid
-    ret = requests.get(API_URL)
-    ret = ret.json()
+    async with aiohttp.ClientSession(headers=header1) as session:
+        async with session.get(url=API_URL, headers=header1) as response:
+            result = await response.read()
+            ret = json.loads(result)
     # nonebot.logger.info(ret)
     return ret
 
@@ -668,8 +791,9 @@ async def get_base_info(uid):
 # 传入uid获取用户直播间房间号
 async def get_room_id(uid):
     API_URL = 'https://api.live.bilibili.com/room/v2/Room/room_id_by_uid?uid=' + uid
-    ret = requests.get(API_URL)
-    ret = ret.json()
+    async with aiohttp.ClientSession(headers=header1) as session:
+        async with session.get(url=API_URL, headers=header1) as response:
+            ret = await response.json()
     try:
         room_id = ret['data']['room_id']
     except TypeError:
@@ -679,32 +803,38 @@ async def get_room_id(uid):
 
 # 获取舰团信息
 async def get_guard_info(uid, room_id):
-    API_URL = 'https://api.live.bilibili.com/xlive/app-room/v2/guardTab/topList?roomid=' + str(room_id) + '&page=1&ruid=' + uid + '&page_size=0'
-    ret = requests.get(API_URL)
-    ret = ret.json()
+    API_URL = 'https://api.live.bilibili.com/xlive/app-room/v2/guardTab/topList?roomid=' + str(
+        room_id) + '&page=1&ruid=' + uid + '&page_size=0'
+    async with aiohttp.ClientSession(headers=header1) as session:
+        async with session.get(url=API_URL, headers=header1) as response:
+            ret = await response.json()
     return ret
 
 
 async def get_user_keyword_info(name):
     API_URL = 'https://api.bilibili.com/x/web-interface/search/type?page_size=10&keyword=' + name + \
               '&search_type=bili_user'
-    ret = requests.get(API_URL, headers=header1)
-    ret = ret.json()
+    async with aiohttp.ClientSession(headers=header1) as session:
+        async with session.get(url=API_URL, headers=header1) as response:
+            ret = await response.json()
     # nonebot.logger.info(ret)
     return ret
 
 
 async def get_user_guard(uid):
     API_URL = 'https://api.tokyo.vtbs.moe/v1/guard/' + uid
-    ret = requests.get(API_URL)
-    ret = ret.json()
+    async with aiohttp.ClientSession(headers=header1) as session:
+        async with session.get(url=API_URL, headers=header1) as response:
+            ret = await response.json()
     # nonebot.logger.info(ret)
     return ret
 
+
 async def get_user_info(uid):
     API_URL = 'https://danmaku.suki.club/api/search/user/channel?uid=' + uid
-    ret = requests.get(API_URL, verify=False)
-    ret = ret.json()
+    async with aiohttp.ClientSession(headers=header1) as session:
+        async with session.get(url=API_URL, headers=header1) as response:
+            ret = await response.json()
     # nonebot.logger.info(ret)
     return ret
 
@@ -712,24 +842,38 @@ async def get_user_info(uid):
 async def get_detail_info(src_uid, tgt_uid, page, page_size):
     API_URL = 'https://danmaku.suki.club/api/search/user/detail?uid=' + src_uid + '&target=' + tgt_uid + \
               '&pagenum=' + page + '&pagesize=' + page_size
-    ret = requests.get(API_URL, verify=False)
-    ret = ret.json()
+    async with aiohttp.ClientSession(headers=header1) as session:
+        async with session.get(url=API_URL, headers=header1) as response:
+            ret = await response.json()
     # nonebot.logger.info(ret)
     return ret
 
 
 async def get_info(uid):
     API_URL = 'https://danmaku.suki.club/api/info/channel?cid=' + uid
-    ret = requests.get(API_URL, verify=False)
-    ret = ret.json()
+    async with aiohttp.ClientSession(headers=header1) as session:
+        async with session.get(url=API_URL, headers=header1) as response:
+            ret = await response.json()
     # nonebot.logger.info(ret)
     return ret
 
 
 async def get_live_info(live_id, income_type):
     API_URL = 'https://danmaku.suki.club/api/info/live?liveid=' + live_id + '&type=' + income_type + '&uid='
-    ret = requests.get(API_URL, verify=False)
-    ret = ret.json()
+    async with aiohttp.ClientSession(headers=header1) as session:
+        async with session.get(url=API_URL, headers=header1) as response:
+            ret = await response.json()
+    # nonebot.logger.info(ret)
+    return ret
+
+
+# 通过昵称查询信息
+async def use_name_get_uid2(name):
+    API_URL = 'https://api.bilibili.com/x/web-interface/search/type?page_size=10&keyword=' + name + \
+              '&search_type=bili_user'
+    async with aiohttp.ClientSession(headers=header1) as session:
+        async with session.get(url=API_URL, headers=header1) as response:
+            ret = await response.json()
     # nonebot.logger.info(ret)
     return ret
 
@@ -738,8 +882,9 @@ async def get_live_info(live_id, income_type):
 async def use_name_get_uid(name):
     API_URL = 'https://api.bilibili.com/x/web-interface/search/type?page_size=10&keyword=' + name + \
               '&search_type=bili_user'
-    ret = requests.get(API_URL, headers=header1)
-    ret = ret.json()
+    async with aiohttp.ClientSession(headers=header1) as session:
+        async with session.get(url=API_URL, headers=header1) as response:
+            ret = await response.json()
     # nonebot.logger.info(ret)
     return ret
 
@@ -750,4 +895,3 @@ async def timestamp_to_date(timestamp):
     # 转换成新的时间格式(精确到秒)
     dt = time.strftime("%Y-%m-%d %H:%M:%S", time_local)
     return dt  # 2021-11-09 09:46:48
-
